==> haskell-wai-app-file-cgi-3.1.11-11-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-file-cgi
version:              3.1.11
visibility:           public
id:                   wai-app-file-cgi-3.1.11-GeunBD45UB93rb9bF43P7H
key:                  wai-app-file-cgi-3.1.11-GeunBD45UB93rb9bF43P7H
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  e507128125a40bb7cc0da2f4da0956af
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.11-GeunBD45UB93rb9bF43P7H
depends:
    array-0.5.6.0 attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6 containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    filepath-1.4.300.1 http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-date-0.0.11-9AFt6UkMptmCfRQJmnvzGs
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ process-1.6.19.0
    sockaddr-0.0.1-Ghn0nteUt1o230LvZgjFZi
    static-hash-0.0.2-2AYu6PGz3wRVTiSzP2qs3 text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0 wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-conduit-3.0.0.4-5k9A8KiBEnMDVxxiIVNGlK
    warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-file-cgi-3.1.11-13-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-file-cgi
version:              3.1.11
visibility:           public
id:                   wai-app-file-cgi-3.1.11-Dbn4LFpX6Z19lJulMhjVJb
key:                  wai-app-file-cgi-3.1.11-Dbn4LFpX6Z19lJulMhjVJb
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  7f5bcd17de683b9730d8e010ba807ba3
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.11-Dbn4LFpX6Z19lJulMhjVJb
depends:
    array-0.5.6.0 attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8PStX6cixKCLkUJoPuARL
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    filepath-1.4.300.1 http-client-0.7.19-HYRPxJ1velFCbteX9ut4f6
    http-conduit-2.3.9.1-4XCjseDTPMR1cOfyxjAQAe
    http-date-0.0.11-4ysForz95Bd3k30KUutCqj
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X process-1.6.19.0
    sockaddr-0.0.1-AriYn2SjPpM88DwrlYWWKP
    static-hash-0.0.2-9sAeWOqDJdhJgGq9nDfEP7 text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0 wai-3.2.4-BLc210LwMQhDvJHRqgIjev
    wai-conduit-3.0.0.4-AtX5Kn5Nm0d7G7lWKPVniL
    warp-3.4.0-Js0YTJVu1i5Lh7vUHNAyGE
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
